@@ -10,9 +10,8 @@
 package Apache::Session::File;
 
 use strict;
-use vars qw($VERSION @ISA);
+use vars qw(@ISA);
 
-$VERSION = '0.99.0';
 @ISA = qw(Apache::Session);
 
 use Apache::Session;
@@ -20,11 +19,23 @@ use Apache::Session::NullLocker;
 use Apache::Session::FileStore;
 
 sub get_object_store {
-    new Apache::Session::FileStore;
+    my $self = shift;
+
+    if(!defined $self->{_object_store}) {
+        $self->{_object_store} = new Apache::Session::FileStore;
+    }
+    
+    return $self->{_object_store}
 }
 
 sub get_lock_manager {
-    new Apache::Session::NullLocker;
+    my $self = shift;
+    
+    if(!defined $self->{_lock_manager}) {
+        $self->{_lock_manager} = new Apache::Session::PosixFileLocker;
+    }
+    
+    return $self->{_lock_manager}
 }
 
 1;
